# Generated by Django 4.2.23 on 2025-12-27 10:52

# Django
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0042_optimize_materialexchangestock"),
    ]

    operations = [
        migrations.AlterField(
            model_name="materialexchangestock",
            name="created_at",
            field=models.DateTimeField(
                default=django.utils.timezone.now, editable=False
            ),
        ),
    ]
