# Generated by Django 4.2.21 on 2025-06-03 19:18

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0002_blueprint_character_name_industryjob_character_name"),
    ]

    operations = [
        migrations.AddField(
            model_name="characterupdatetracker",
            name="last_refresh_request",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
