# Generated by ChatGPT on 2024-11-10
# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0036_blueprintcopychat_buyer_last_seen_at_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="corporationsharingsetting",
            name="authorized_characters",
            field=models.JSONField(blank=True, default=list),
        ),
    ]
