# Generated by Django 4.2.23 on 2025-11-01 10:24

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0038_alter_charactersettings_options"),
    ]

    operations = [
        migrations.AlterField(
            model_name="charactersettings",
            name="copy_sharing_scope",
            field=models.CharField(
                choices=[
                    ("none", "None"),
                    ("corporation", "Corporation"),
                    ("alliance", "Alliance"),
                    ("everyone", "Everyone"),
                ],
                default="none",
                max_length=20,
            ),
        ),
        migrations.AlterField(
            model_name="corporationsharingsetting",
            name="share_scope",
            field=models.CharField(
                choices=[
                    ("none", "None"),
                    ("corporation", "Corporation"),
                    ("alliance", "Alliance"),
                    ("everyone", "Everyone"),
                ],
                default="none",
                max_length=20,
            ),
        ),
    ]
