# Generated by Django 4.2.23 on 2025-12-30 21:39

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0056_random_order_references"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="materialexchangebuyorder",
            new_name="indy_hub_ma_esi_con_f75c4b_idx",
            old_name="indy_hub_me_buy_esi_con_idx",
        ),
        migrations.RenameIndex(
            model_name="materialexchangesellorder",
            new_name="indy_hub_ma_esi_con_05a3e3_idx",
            old_name="indy_hub_me_esi_con_idx",
        ),
    ]
