# Generated by Django 4.2.21 on 2025-06-08 14:12

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0006_blueprint_copy_share_and_request"),
    ]

    operations = [
        migrations.AlterField(
            model_name="blueprintcopyrequest",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="blueprintcopysharesetting",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
