.bp-request-grid__cell {
    flex: 0 0 auto;
    width: 270px;
}

.bp-request-grid__cell .bp-request-card {
    width: 100%;
}

@media (max-width: 575.98px) {
    .bp-request-grid__cell {
        width: 100%;
        max-width: 270px;
    }
}
