# Generated by ChatGPT on 2025-10-14
# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0026_allow_duplicate_copy_requests"),
    ]

    operations = []
