{% load i18n %}
<div id="indy-hub-popup" class="indy-hub-popup" data-popup-type="info" role="status" aria-live="polite" aria-atomic="true">
    <div class="indy-hub-popup-icon" aria-hidden="true">
        <i class="fas fa-circle-info"></i>
    </div>
    <div class="indy-hub-popup-message" id="indy-hub-popup-message"></div>
    <button type="button" class="indy-hub-popup-dismiss" aria-label="{% trans 'Dismiss notification' %}">
        <i class="fas fa-xmark"></i>
    </button>
</div>
