# Generated by Django 4.2.23 on 2025-12-27 11:14

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0044_materialexchangeconfig_buy_markup_base_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="materialexchangebuyorder",
            name="esi_contract_id",
            field=models.BigIntegerField(
                blank=True, help_text="ESI contract ID for this buy order", null=True
            ),
        ),
        migrations.AddField(
            model_name="materialexchangebuyorder",
            name="esi_contract_validated",
            field=models.BooleanField(
                default=False,
                help_text="Whether ESI validation confirmed contract completion",
            ),
        ),
        migrations.AddField(
            model_name="materialexchangebuyorder",
            name="esi_validation_checked_at",
            field=models.DateTimeField(
                blank=True, help_text="Last time ESI contract was validated", null=True
            ),
        ),
        migrations.AddField(
            model_name="materialexchangesellorder",
            name="esi_contract_id",
            field=models.BigIntegerField(
                blank=True, help_text="ESI contract ID for this sell order", null=True
            ),
        ),
        migrations.AddField(
            model_name="materialexchangesellorder",
            name="esi_contract_validated",
            field=models.BooleanField(
                default=False,
                help_text="Whether ESI validation confirmed contract items",
            ),
        ),
        migrations.AddField(
            model_name="materialexchangesellorder",
            name="esi_validation_checked_at",
            field=models.DateTimeField(
                blank=True, help_text="Last time ESI contract was validated", null=True
            ),
        ),
    ]
