# Generated by Copilot: add copies_requested to BlueprintCopyRequest
# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("indy_hub", "0007_alter_blueprintcopyrequest_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="blueprintcopyrequest",
            name="copies_requested",
            field=models.IntegerField(default=1),
        ),
    ]
