# Generated by Django 4.2.23 on 2025-12-30 16:58

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0053_add_esi_contract_models"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="esicontract",
            new_name="indy_hub_es_corpora_e83e14_idx",
            old_name="indy_hub_es_corpora_c8d8a5_idx",
        ),
        migrations.RenameIndex(
            model_name="esicontract",
            new_name="indy_hub_es_issuer__abacd7_idx",
            old_name="indy_hub_es_issuer__9c8e3e_idx",
        ),
        migrations.RenameIndex(
            model_name="esicontract",
            new_name="indy_hub_es_accepto_e51feb_idx",
            old_name="indy_hub_es_accepto_6f7c4a_idx",
        ),
        migrations.RenameIndex(
            model_name="esicontract",
            new_name="indy_hub_es_date_is_a0f169_idx",
            old_name="indy_hub_es_date_is_2e1f5b_idx",
        ),
        migrations.RenameIndex(
            model_name="esicontractitem",
            new_name="indy_hub_es_contrac_c6f466_idx",
            old_name="indy_hub_es_contrac_7a2b3c_idx",
        ),
        migrations.RenameIndex(
            model_name="esicontractitem",
            new_name="indy_hub_es_type_id_6fcbb3_idx",
            old_name="indy_hub_es_type_id_4d5e6f_idx",
        ),
    ]
